import * as bcrypt from 'bcrypt';
import { Injectable } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';

@Injectable()
export class BcryptService {
  private salt: string;
  private passwordLength: number;

  constructor(private configService: ConfigService) {
    this.salt = bcrypt.genSaltSync(
      parseInt(this.configService.get<string>('SALT_ROUNDS')),
    );
    this.passwordLength = parseInt(
      this.configService.get<string>('PASSWORD_LENGTH'),
    );
  }

  comparar(password: string, passwordDb: string): boolean {
    return bcrypt.compareSync(password, passwordDb);
  }

  encriptar(password: string): string {
    return bcrypt.hashSync(password, this.salt);
  }

  generarPassword(): string {
    const charset =
      'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+-@#$%&=?¿*()/_-';
    let password = '';

    for (let i = 0; i < this.passwordLength; i++)
      password += charset.charAt(Math.floor(Math.random() * charset.length));
    return password;
  }
}
