import { forwardRef, Module } from '@nestjs/common';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { EquipoController } from './equipo.controller';
import { EquipoService } from './equipo.service';
import { Equipo } from './entity/equipo.entity';
import { FullInformacionEquipoView } from './entity/views/full-informacion-equipo.view';
import { InformacionEquipoView } from './entity/views/informacion-equipo.view';
import { InformacionEquipoPrestamoView } from './entity/views/informacion-equipo-prestamo.view';
import { CarritoModule } from '../carrito/carrito.module';
import { EquipoMotivoModule } from '../equipo-motivo/equipo-motivo.module';
import { EquipoProgramaModule } from '../equipo-programa/equipo-programa.module';
import { EquipoTipoEntradaModule } from '../equipo-tipo-entrada/equipo-tipo-entrada.module';
import { InstitucionModule } from '../institucion/institucion.module';
import { InstitucionProgramaModule } from '../institucion-programa/institucion-programa.module';
import { InstitucionTipoCarritoModule } from '../institucion-tipo-carrito/institucion-tipo-carrito.module';
import { InstitucionTipoEntradaModule } from '../institucion-tipo-entrada/institucion-tipo-entrada.module';
import { MarcaModule } from '../marca/marca.module';
import { ModeloModule } from '../modelo/modelo.module';
import { ModuloModule } from '../modulo/modulo.module';
import { OperadorModule } from '../operador/operador.module';
import { StatusModule } from '../status/status.module';

@Module({
  imports: [
    CarritoModule,
    forwardRef(() => EquipoMotivoModule),
    forwardRef(() => EquipoProgramaModule),
    forwardRef(() => EquipoTipoEntradaModule),
    InstitucionModule,
    InstitucionProgramaModule,
    InstitucionTipoCarritoModule,
    InstitucionTipoEntradaModule,
    MarcaModule,
    ModeloModule,
    ModuloModule,
    OperadorModule,
    PassportModule.register({ defaultStrategy: 'jwt' }),
    StatusModule,
    TypeOrmModule.forFeature([
      Equipo,
      FullInformacionEquipoView,
      InformacionEquipoView,
      InformacionEquipoPrestamoView,
    ]),
  ],
  controllers: [EquipoController],
  providers: [EquipoService],
  exports: [EquipoService],
})
export class EquipoModule {}
