import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../../../equipo/entity/equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { InstitucionCarrera } from '../../../institucion-carrera/entity/institucion-carrera.entity';
import { InstitucionUsuario } from '../../../institucion-usuario/entity/institucion-usuario.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { Operador } from '../../../operador/entity/operador.entity';
import { Prestamo } from '../prestamo.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';
import { TipoUsuario } from '../../../tipo-usuario/entity/tipo-usuario.entity';
import { Usuario } from '../../../usuario/entity/usuario.entity';
import { Carrera } from '../../../institucion-carrera/entity/carrera.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('p.id_prestamo', 'id_prestamo')
      .addSelect('p.activo', 'activo')
      .addSelect('p.cancelado_operador', 'cancelado_operador')
      .addSelect('p.cancelado_usuario', 'cancelado_usuario')
      .addSelect('p.fecha_entrega', 'fecha_entrega')
      .addSelect('p.fecha_inicio', 'fecha_inicio')
      .addSelect('p.hora_fin', 'hora_fin')
      .addSelect('p.hora_inicio', 'hora_inicio')
      .addSelect('p.hora_max_recoger', 'hora_max_recoger')
      .addSelect('p.id_equipo', 'id_equipo')
      .addSelect('p.id_institucion_usuario', 'id_institucion_usuario')
      .addSelect('p.id_operador_entrega', 'id_operador_entrega')
      .addSelect('p.id_operador_regreso', 'id_operador_regreso')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('iu.id_institucion_carrera', 'id_institucion_carrera')
      .addSelect('iu.id_usuario', 'id_usuario')
      .addSelect('oe.operador', 'operador_entrega')
      .addSelect('or.operador', 'operador_regreso')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('ic.id_carrera', 'id_carrera')
      .addSelect('u.id_tipo_usuario', 'id_tipo_usuario')
      .addSelect('u.nombre', 'nombre')
      .addSelect('u.usuario', 'usuario')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('m.modulo', 'modulo')
      .addSelect('tu.tipo_usuario', 'tipo_usuario')
      .addSelect('tc.tipo_carrito', 'tipo_carrito')
      .addSelect('i.institucion', 'institucion')
      .addSelect('ca.carrera', 'carrera')
      .from(Prestamo, 'p')
      .innerJoin(Equipo, 'e', 'e.id_equipo = p.id_equipo')
      .innerJoin(
        InstitucionUsuario,
        'iu',
        'iu.id_institucion_usuario = p.id_institucion_usuario',
      )
      .innerJoin(Operador, 'oe', 'oe.id_operador = p.id_operador_entrega')
      .innerJoin(Operador, 'or', 'or.id_operador = p.id_operador_regreso')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(
        InstitucionCarrera,
        'ic',
        'ic.id_institucion_carrera = iu.id_institucion_carrera',
      )
      .innerJoin(Usuario, 'u', 'u.id_usuario = iu.id_usuario')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoUsuario, 'tu', 'tu.id_tipo_usuario = u.id_tipo_usuario')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion')
      .innerJoin(Carrera, 'ca', 'ca.id_carrera = ic.id_carrera')
      .orderBy('i.institucion')
      .addOrderBy('p.id_prestamo'),
})
export class FullInformacionPrestamoView {
  @ViewColumn()
  id_prestamo: number;

  @ViewColumn()
  activo: number;

  @ViewColumn()
  cancelado_operador: number;

  @ViewColumn()
  cancelado_usuario: number;

  @ViewColumn()
  carrera: string;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  fecha_entrega: Date;

  @ViewColumn()
  fecha_inicio: Date;

  @ViewColumn()
  hora_fin: Date;

  @ViewColumn()
  hora_inicio: Date;

  @ViewColumn()
  hora_max_recoger: Date;

  @ViewColumn()
  id_carrera: number;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_institucion_carrera: number;

  @ViewColumn()
  id_institucion_usuario: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_operador_entrega: number;

  @ViewColumn()
  id_operador_regreso: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_tipo_usuario: number;

  @ViewColumn()
  id_usuario: number;

  @ViewColumn()
  institucion: string;

  @ViewColumn()
  modulo: string;

  @ViewColumn()
  nombre: string;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  operador_entrega: string;

  @ViewColumn()
  operador_regreso: string;

  @ViewColumn()
  tipo_carrito: string;

  @ViewColumn()
  tipo_usuario: string;

  @ViewColumn()
  usuario: string;
}
